@@ -1,8 +1,8 @@
 from multiprocessing.managers import BaseManager
-from common.protocol import DEFAULT_SIMPLE_AGENT_NAME
-from common.protocol import DEFAULT_UNIQUE_KEY_AGENT_NAME
-from clients.simple_agent_client import SimpleAgentClient
-from clients.unique_key_agent_client import UniqueKeyAgentClient
+from .common.protocol import DEFAULT_SIMPLE_AGENT_NAME
+from .common.protocol import DEFAULT_UNIQUE_KEY_AGENT_NAME
+from .clients.simple_agent_client import SimpleAgentClient
+from .clients.unique_key_agent_client import UniqueKeyAgentClient
 from loguru import logger
 
 class ClientFactory:
