@@ -1,11 +1,11 @@
 import sys
 from multiprocessing.managers import BaseManager
-from brokers.simple_topic_agent import SimpleTopicAgent
-from brokers.unique_key_topic_agent import UniqueKeyTopicAgent
+from .brokers.simple_topic_agent import SimpleTopicAgent
+from .brokers.unique_key_topic_agent import UniqueKeyTopicAgent
 from flask import Flask
 from flask import jsonify
-from common.protocol import DEFAULT_SIMPLE_AGENT_NAME
-from common.protocol import DEFAULT_UNIQUE_KEY_AGENT_NAME
+from .common.protocol import DEFAULT_SIMPLE_AGENT_NAME
+from .common.protocol import DEFAULT_UNIQUE_KEY_AGENT_NAME
 from loguru import logger
 import threading
 
